@@ -37,7 +37,7 @@
 
 pref("general.useragent.vendor", "Thunderbird");
 pref("general.useragent.vendorSub", 
-"1.0.2"
+"1.0.6"
 );
 
 // This is this application's unique identifier used by the Extension System to identify
@@ -45,10 +45,10 @@ pref("general.useragent.vendorSub",
 // this application to the Update server.
 pref("app.id", "{3550f703-e582-4d05-9a08-453d09bdfdc6}");
 pref("app.version", 
-"1.0.2"
+"1.0.6"
 );
 pref("app.build_id", 
-"2005031704"
+"2005071604"
 );
 pref("app.extensions.version", "1.0");
 
@@ -110,7 +110,8 @@ pref("update.showSlidingNotification", true);   // Windows-only slide-up taskbar
 // 2 = high   (new version of Firefox/Security patch)
 pref("update.severity", 0); 
 
-pref("xpinstall.whitelist.add", "update.mozilla.org,addons.mozilla.org");
+pref("xpinstall.whitelist.add", "update.mozilla.org");
+pref("xpinstall.whitelist.add.103", "addons.mozilla.org");
 
 /////////////////////////////////////////////////////////////////
 // Overrides of the seamonkey suite mailnews.js prefs
@@ -161,7 +162,7 @@ pref("mail.checkDefaultNews", false);
 /////////////////////////////////////////////////////////////////
 
 // l12n and i18n
-pref("general.useragent.locale", "de-DE");
+pref("general.useragent.locale", "ru-RU");
 pref("general.skins.selectedSkin", "classic/1.0");
 
 pref("intl.charsetmenu.mailedit", "chrome://global/locale/intl.properties");
